@@ -182,7 +182,7 @@ bool MigrateApplicationFiles::copyRecursively(const QString &srcFilePath, const
             qCDebug(PIMCOMMON_LOG) << "Can not create path " << srcFileInfo.absolutePath();
             return false;
         }
-        if (!QFile(tgtFilePath).exists() && !QFile::copy(srcFilePath, tgtFilePath)) {
+        if (!QFileInfo::exists(tgtFilePath) && !QFile::copy(srcFilePath, tgtFilePath)) {
             qCDebug(PIMCOMMON_LOG) << " can't copy" << srcFilePath << " tgtFilePath" << tgtFilePath;
             return false;
         }
@@ -205,8 +205,7 @@ void MigrateApplicationFiles::migrateFile(const MigrateFileInfo &info)
 
     if (!originalPath.isEmpty()) {
         if (info.filePatterns().isEmpty()) {
-            QFile newFile(newPath);
-            if (!newFile.exists()) {
+            if (!QFileInfo::exists(newPath)) {
                 QFile copyFile(originalPath);
                 if (!copyFile.copy(newPath)) {
                     qCDebug(PIMCOMMON_LOG) << "impossible to copy " << originalPath << " to " << newPath;
